package com.ruoyi.project.zjsgfa.service;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjFdsgcsDcyx;

/**
 * 设计-分段施工措施-地层岩性Service接口
 * 
 * @author ruoyi
 * @date 2025-08-06
 */
public interface ISjFdsgcsDcyxService 
{
    /**
     * 查询设计-分段施工措施-地层岩性
     * 
     * @param id 设计-分段施工措施-地层岩性主键
     * @return 设计-分段施工措施-地层岩性
     */
    public SjFdsgcsDcyx selectSjFdsgcsDcyxById(Long id);

    /**
     * 查询设计-分段施工措施-地层岩性列表
     * 
     * @param sjFdsgcsDcyx 设计-分段施工措施-地层岩性
     * @return 设计-分段施工措施-地层岩性集合
     */
    public List<SjFdsgcsDcyx> selectSjFdsgcsDcyxList(SjFdsgcsDcyx sjFdsgcsDcyx);

    /**
     * 新增设计-分段施工措施-地层岩性
     * 
     * @param sjFdsgcsDcyx 设计-分段施工措施-地层岩性
     * @return 结果
     */
    public int insertSjFdsgcsDcyx(SjFdsgcsDcyx sjFdsgcsDcyx);

    /**
     * 修改设计-分段施工措施-地层岩性
     * 
     * @param sjFdsgcsDcyx 设计-分段施工措施-地层岩性
     * @return 结果
     */
    public int updateSjFdsgcsDcyx(SjFdsgcsDcyx sjFdsgcsDcyx);

    /**
     * 批量删除设计-分段施工措施-地层岩性
     * 
     * @param ids 需要删除的设计-分段施工措施-地层岩性主键集合
     * @return 结果
     */
    public int deleteSjFdsgcsDcyxByIds(Long[] ids);

    /**
     * 删除设计-分段施工措施-地层岩性信息
     * 
     * @param id 设计-分段施工措施-地层岩性主键
     * @return 结果
     */
    public int deleteSjFdsgcsDcyxById(Long id);
}
